"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MysqlBaseConfig = exports.ConstraintSnakeNamingStrategy = void 0;
require("dotenv/config");
const typeorm_1 = require("typeorm");
const typeorm_naming_strategies_1 = require("typeorm-naming-strategies");
const crypto = require("crypto");
function createHash(algorithm = "md5", str) {
    return crypto.createHash(algorithm).update(str).digest("hex");
}
class ConstraintSnakeNamingStrategy extends typeorm_naming_strategies_1.SnakeNamingStrategy {
    constructor() {
        super();
    }
    primaryKeyName(tableOrName, columnNames) {
        const table = tableOrName instanceof typeorm_1.Table ? tableOrName.name : tableOrName;
        const columnsSnakeCase = columnNames.join("_");
        return `pk_${table}_${columnsSnakeCase}`;
    }
    foreignKeyName(tableOrName, columnNames, referencedTablePath) {
        tableOrName =
            typeof tableOrName === "string" ? tableOrName : tableOrName.name;
        const name = columnNames.reduce((name, column) => `${name}_${column}`, `${tableOrName}_${referencedTablePath}`);
        return `fk_${createHash("md5", name)}`;
    }
}
exports.ConstraintSnakeNamingStrategy = ConstraintSnakeNamingStrategy;
const mysqlDatabase = "mysql";
const MysqlBaseConfig = (host, port, username, password, database, any) => {
    const base = {
        type: mysqlDatabase,
        host,
        port: parseInt(port, 10),
        username,
        password,
        database,
        synchronize: false,
        logging: false,
        autoLoadEntities: true,
        extra: {
            connectionLimit: 5000,
        },
        charset: "utf8mb4",
        namingStrategy: new ConstraintSnakeNamingStrategy(),
        entities: ["src/**/*.entity.ts"],
        subscribers: ["src/**/*.subscribe.ts"],
    };
    if (any) {
        return Object.assign(base, Object.assign({}, any));
    }
    return base;
};
exports.MysqlBaseConfig = MysqlBaseConfig;
//# sourceMappingURL=mysql.base.js.map