"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServiceBase = void 0;
const crud_typeorm_1 = require("@nestjsx/crud-typeorm");
class ServiceBase extends crud_typeorm_1.TypeOrmCrudService {
    constructor(repo) {
        super(repo);
        this.repo = repo;
    }
    get entity() {
        return this.repo.target;
    }
    async findOneBy(options, manager) {
        if (manager) {
            return manager.findOne(this.entity, options);
        }
        return this.repo.findOne(options);
    }
    async findAllBy(options, manager) {
        if (manager) {
            return manager.find(this.entity, options);
        }
        return this.repo.find(options);
    }
    async createOneBy(params, manager) {
        const item = this.repo.create(params);
        if (manager) {
            return (await manager.insert(this.entity, item))
                .generatedMaps[0];
        }
        return (await this.repo.insert(item)).generatedMaps[0];
    }
    async createAllBy(params, manager) {
        const createEntities = params.map((param) => this.repo.create(param));
        if (manager) {
            return manager.save(this.entity, createEntities);
        }
        return this.repo.save(createEntities);
    }
    async createAllIfNotExistBy(params, manager) {
        const createEntities = params.map((param) => this.repo.create(param));
        let queryBuilder;
        if (manager) {
            queryBuilder = manager.createQueryBuilder();
        }
        else {
            queryBuilder = this.repo.createQueryBuilder();
        }
        return queryBuilder
            .insert()
            .into(this.entity)
            .values(createEntities)
            .orIgnore()
            .execute();
    }
    async createOrUpdateAllBy(params, manager) {
        if (manager) {
            return manager.save(this.entity, params);
        }
        return this.repo.save(params);
    }
    async updateOneBy(where, set, manager) {
        if (manager) {
            return manager.update(this.entity, where, set);
        }
        return this.repo.update(where, set);
    }
    async deleteOneBy(where, manager) {
        if (manager) {
            return manager.delete(this.entity, where);
        }
        return this.repo.delete(where);
    }
}
exports.ServiceBase = ServiceBase;
//# sourceMappingURL=service.base.js.map