"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InteractionService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("@nestjs/typeorm");
const interaction_entity_1 = require("./interaction.entity");
const typeorm_2 = require("typeorm");
const token_entity_1 = require("../token/token.entity");
const farm_entity_1 = require("../farm/farm.entity");
const interaction_constant_1 = require("./interaction.constant");
const lending_entity_1 = require("../lending/lending.entity");
const nf_token_entity_1 = require("../nf-token/nf-token.entity");
const service_base_1 = require("../app/service.base");
let InteractionService = class InteractionService extends service_base_1.ServiceBase {
    constructor(repo) {
        super(repo);
        this.repo = repo;
    }
    async getTokenInteractions(address, network) {
        const queryBuilder = this.repo
            .createQueryBuilder("interaction")
            .innerJoinAndMapOne("interaction.token", token_entity_1.Token, "token", `interaction.contractAddress = token.address 
        AND interaction.network = token.network 
        AND token.status = true`)
            .leftJoinAndSelect("token.network", "network")
            .leftJoinAndSelect("token.pair0", "pair0")
            .leftJoinAndSelect("token.pair1", "pair1")
            .leftJoinAndSelect("token.wrapped", "wrapped")
            .where("interaction.type = :type", { type: interaction_constant_1.INTERACTION_TYPE.TOKEN })
            .andWhere("interaction.address = :address", { address })
            .andWhere("network.status = true");
        if (network) {
            queryBuilder.andWhere("network.id = :networkId", {
                networkId: network.id,
            });
        }
        const interactions = await queryBuilder.getMany();
        return interactions.map(({ token }) => token);
    }
    async getFarmInteractions(address, network) {
        const queryBuilder = this.repo
            .createQueryBuilder("interaction")
            .innerJoinAndMapOne("interaction.farm", farm_entity_1.Farm, "farm", `interaction.contractAddress = farm.address 
          AND interaction.referPid = farm.pid 
          AND interaction.referAddress = farm.poolAddress 
          AND farm.status = true`)
            .leftJoinAndSelect("farm.protocol", "protocol")
            .leftJoinAndSelect("protocol.network", "network")
            .leftJoinAndSelect("farm.stakeTokens", "stakeTokens")
            .leftJoinAndSelect("stakeTokens.pair0", "stakeTokenPair0")
            .leftJoinAndSelect("stakeTokens.pair1", "stakeTokenPair1")
            .leftJoinAndSelect("stakeTokens.wrapped", "stakeTokenWrapped")
            .leftJoinAndSelect("farm.rewardTokens", "rewardTokens")
            .leftJoinAndSelect("rewardTokens.pair0", "rewardTokenPair0")
            .leftJoinAndSelect("rewardTokens.pair1", "rewardTokenPair1")
            .leftJoinAndSelect("rewardTokens.wrapped", "rewardTokenWrapped")
            .where("interaction.type = :type", { type: interaction_constant_1.INTERACTION_TYPE.FARM })
            .andWhere("interaction.address = :address", { address })
            .andWhere("protocol.status = true")
            .andWhere("network.status = true");
        if (network) {
            queryBuilder.andWhere("network.id = :networkId", {
                networkId: network.id,
            });
        }
        const interactions = await queryBuilder.getMany();
        return interactions.map(({ farm }) => farm);
    }
    async getLendingInteractions(address, network) {
        const queryBuilder = this.repo
            .createQueryBuilder("interaction")
            .innerJoinAndMapOne("interaction.lending", lending_entity_1.Lending, "lending", `interaction.contractAddress = lending.address 
          AND interaction.referPid = lending.pid 
          AND interaction.referAddress = lending.marketAddress 
          AND lending.status = true`)
            .leftJoinAndSelect("lending.protocol", "protocol")
            .leftJoinAndSelect("protocol.network", "network")
            .leftJoinAndSelect("lending.supplyTokens", "supplyTokens")
            .leftJoinAndSelect("lending.borrowTokens", "borrowTokens")
            .where("interaction.type = :type", { type: interaction_constant_1.INTERACTION_TYPE.LENDING })
            .andWhere("interaction.address = :address", { address })
            .andWhere("protocol.status = true")
            .andWhere("network.status = true");
        if (network) {
            queryBuilder.andWhere("network.id = :networkId", {
                networkId: network.id,
            });
        }
        const interactions = await queryBuilder.getMany();
        return interactions.map(({ lending }) => lending);
    }
    async getERC721NFTokenInteractions(address, network) {
        const queryBuilder = this.repo
            .createQueryBuilder("interaction")
            .innerJoinAndMapOne("interaction.nfToken", nf_token_entity_1.NFToken, "nfToken", `interaction.contractAddress = nfToken.address
       AND nfToken.status = true`)
            .leftJoinAndSelect("nfToken.network", "network")
            .where("interaction.type = :type", {
            type: interaction_constant_1.INTERACTION_TYPE.NF_TOKEN_ERC721,
        })
            .andWhere("interaction.address = :address", { address })
            .andWhere("network.status = true");
        if (network) {
            queryBuilder.andWhere("network.id = :networkId", {
                networkId: network.id,
            });
        }
        const interactions = await queryBuilder.getMany();
        return interactions.map(({ nfToken }) => nfToken);
    }
    async getERC1155NFTokenInteractions(address, network) {
        const queryBuilder = this.repo
            .createQueryBuilder("interaction")
            .innerJoinAndMapOne("interaction.nfToken", nf_token_entity_1.NFToken, "nfToken", `interaction.contractAddress = nfToken.address
       AND nfToken.status = true`)
            .leftJoinAndSelect("nfToken.network", "network")
            .where("interaction.type = :type", {
            type: interaction_constant_1.INTERACTION_TYPE.NF_TOKEN_ERC1155,
        })
            .andWhere("interaction.address = :address", { address })
            .andWhere("network.status = true");
        if (network) {
            queryBuilder.andWhere("network.id = :networkId", {
                networkId: network.id,
            });
        }
        const interactions = await queryBuilder.getMany();
        return interactions.map(({ nfToken }) => nfToken);
    }
};
InteractionService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, typeorm_1.InjectRepository)(interaction_entity_1.Interaction)),
    __metadata("design:paramtypes", [typeorm_2.Repository])
], InteractionService);
exports.InteractionService = InteractionService;
//# sourceMappingURL=interaction.service.js.map